﻿using System;
using System.Windows.Forms;

using Steema.TeeChart.Functions;
using Steema.TeeChart.Styles;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : Form
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 캔들
        /// </summary>
        private Candle candle;

        /// <summary>
        /// 라인
        /// </summary>
        private Line line;

        /// <summary>
        /// 볼린저
        /// </summary>
        private Bollinger bollinger;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            this.periodNumericUpDown.Value    = 50;
            this.deviationNumericUpDown.Value = 2;

            this.candle = new Candle(this.tChart.Chart);

            this.candle.Title               = "Candle";
            this.candle.UseExtendedNumRange = false;

            this.candle.FillSampleValues(400);

            this.bollinger = new Bollinger(this.tChart.Chart);

            this.bollinger.Period    = 50;
            this.bollinger.Deviation = 2;

            this.line = new Line(this.tChart.Chart);

            this.line.Title               = "Bollinger";
            this.line.ColorEach           = false;
            this.line.UseExtendedNumRange = false;
            this.line.DataSource          = this.candle;
            this.line.Function            = this.bollinger;

            Load                                     += Form_Load;
            this.buttonColor.Click                   += buttonColor_Click;
            this.periodNumericUpDown.ValueChanged    += periodNumericUpDown_ValueChanged;
            this.deviationNumericUpDown.ValueChanged += deviationNumericUpDown_ValueChanged;
            this.exponentialCheckBox.Click           += exponentialCheckBox_Click;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 폼 로드시 처리하기 - Form_Load(sender, e)

        /// <summary>
        /// 폼 로드시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void Form_Load(object sender, EventArgs e)
        {
            this.buttonColor.Color = this.line.Color;
        }

        #endregion
        #region 버튼 색상 클릭시 처리하기 - buttonColor_Click(sender, e)

        /// <summary>
        /// 버튼 색상 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void buttonColor_Click(object sender, EventArgs e)
        {
            this.line.Color = this.buttonColor.Color;

            this.bollinger.LowBandPen.Color = this.buttonColor.Color;
        }

        #endregion
        #region 기간 숫자 UP/DOWN 값 변경시 처리하기 - periodNumericUpDown_ValueChanged(sender, e)

        /// <summary>
        /// 기간 숫자 UP/DOWN 값 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void periodNumericUpDown_ValueChanged(object sender, EventArgs e)
        {
            this.bollinger.Period = Convert.ToDouble(this.periodNumericUpDown.Value);
        }

        #endregion
        #region 편차 숫자 UP/DOWN 값 변경시 처리하기 - deviationNumericUpDown_ValueChanged(sender, e)

        /// <summary>
        /// 편차 숫자 UP/DOWN 값 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void deviationNumericUpDown_ValueChanged(object sender, EventArgs e)
        {
            this.bollinger.Deviation = Convert.ToDouble(this.deviationNumericUpDown.Value);
        }

        #endregion
        #region 지수 체크 박스 클릭시 처리하기 - exponentialCheckBox_Click(sender, e)

        /// <summary>
        /// 지수 체크 박스 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void exponentialCheckBox_Click(object sender, EventArgs e)
        {
            this.bollinger.Exponential = this.exponentialCheckBox.Checked;
        }

        #endregion
    }
}